@@ -8,10 +8,17 @@
  * Contributors:
  *   IBM - initial API and implementation
  *
- * $Id: GenerateModelAction.java,v 1.1 2006/03/28 21:07:32 khussey Exp $
+ * $Id: GenerateModelAction.java,v 1.1.2.1 2006/08/16 17:40:08 khussey Exp $
  */
 package org.eclipse.uml2.examples.uml.ui.actions;
 
+import java.util.Collection;
+
+import org.eclipse.emf.common.command.Command;
+import org.eclipse.emf.common.command.IdentityCommand;
+import org.eclipse.emf.common.command.UnexecutableCommand;
+import org.eclipse.emf.edit.domain.EditingDomain;
+import org.eclipse.uml2.uml.Model;
 import org.eclipse.uml2.uml.PrimitiveType;
 import org.eclipse.uml2.uml.UMLPackage;
 import org.eclipse.uml2.uml.editor.actions.UMLCommandAction;
@@ -19,6 +26,18 @@ import org.eclipse.uml2.uml.editor.actions.UMLCommandAction;
 public class GenerateModelAction
 		extends UMLCommandAction {
 
+	protected Command createActionCommand(EditingDomain editingDomain,
+			Collection collection) {
+
+		if (collection.size() == 1
+			&& collection.iterator().next() instanceof Model) {
+
+			return IdentityCommand.INSTANCE;
+		}
+
+		return UnexecutableCommand.INSTANCE;
+	}
+
 	protected PrimitiveType generateOwnedPrimitiveType(
 			org.eclipse.uml2.uml.Package package_, String name) {
 		return (PrimitiveType) package_.getPackagedElement(name, false,
