@@ -8,11 +8,12 @@
  * Contributors:
  *   IBM - initial API and implementation
  *
- * $Id: ElementOperations.java,v 1.44 2006/06/21 13:33:12 khussey Exp $
+ * $Id: ElementOperations.java,v 1.44.2.7 2006/10/25 16:52:18 khussey Exp $
  */
 package org.eclipse.uml2.uml.internal.operations;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
@@ -129,7 +130,7 @@ public class ElementOperations
 			DiagnosticChain diagnostics, Map context) {
 		boolean result = true;
 
-		if (element.allOwnedElements().contains(element)) {
+		if (EcoreUtil.isAncestor(element, element.getOwner())) {
 			result = false;
 
 			if (diagnostics != null) {
@@ -556,7 +557,7 @@ public class ElementOperations
 						: eObject.eGet(eStructuralFeature);
 				}
 
-				if (eType instanceof EEnum) {
+				if (eType instanceof EEnum && value instanceof EEnumLiteral) {
 					EAnnotation eAnnotation = eType
 						.getEAnnotation(UMLPackage.eNS_URI);
 
@@ -1058,13 +1059,21 @@ public class ElementOperations
 			Association association = attribute.getAssociation();
 
 			if (association instanceof Extension) {
-				Type type = attribute.getType();
+				String name = attribute.getName();
 
-				if (type instanceof org.eclipse.uml2.uml.Class) {
-					EClassifier eClassifier = getEClassifier((org.eclipse.uml2.uml.Class) type);
+				if (!isEmpty(name)
+					&& name.startsWith(Extension.METACLASS_ROLE_PREFIX)) {
 
-					if (eClassifier != null && eClassifier.isInstance(element)) {
-						return (Extension) association;
+					Type type = attribute.getType();
+
+					if (type instanceof org.eclipse.uml2.uml.Class) {
+						EClassifier eClassifier = getEClassifier((org.eclipse.uml2.uml.Class) type);
+
+						if (eClassifier != null
+							&& eClassifier.isInstance(element)) {
+
+							return (Extension) association;
+						}
 					}
 				}
 			}
@@ -1458,18 +1467,64 @@ public class ElementOperations
 	 * @generated NOT
 	 */
 	public static void destroy(Element element) {
+		destroy((EObject) element);
+	}
 
-		for (Iterator allContents = getAllContents(element, true, false); allContents
-			.hasNext();) {
+	protected static void destroy(EObject ancestorEObject) {
 
-			EObject eObject = (EObject) allContents.next();
+		if (ancestorEObject.eContents().isEmpty()) {
 
-			if (eObject instanceof Element) {
-				destroyAll(((Element) eObject).getStereotypeApplications());
+			if (ancestorEObject instanceof Element) {
+				destroyAll(((Element) ancestorEObject)
+					.getStereotypeApplications());
+				removeReferences(ancestorEObject, ancestorEObject);
+				ancestorEObject.eAdapters().clear();
+			} else {
+				removeReferences(ancestorEObject, null);
+			}
+		} else {
+
+			for (Iterator allContents = getAllContents(ancestorEObject, true,
+				false); allContents.hasNext();) {
+
+				Object object = allContents.next();
+
+				if (object instanceof Element) {
+					destroyAll(((Element) object).getStereotypeApplications());
+				}
+			}
+
+			for (Iterator allContents = getAllContents(ancestorEObject, true,
+				false); allContents.hasNext();) {
+
+				EObject eObject = (EObject) allContents.next();
+
+				if (eObject instanceof Element) {
+					removeReferences(eObject, ancestorEObject);
+				} else {
+					removeReferences(eObject, null);
+				}
+			}
+
+			for (Iterator allContents = getAllContents(ancestorEObject, true,
+				false); allContents.hasNext();) {
+
+				Object object = allContents.next();
+
+				if (object instanceof Element) {
+					((Element) object).eAdapters().clear();
+				}
 			}
 		}
 
-		destroy((EObject) element);
+		EcoreUtil.remove(ancestorEObject);
+	}
+
+	protected static void destroyAll(Collection eObjects) {
+
+		for (Iterator o = eObjects.iterator(); o.hasNext();) {
+			destroy((EObject) o.next());
+		}
 	}
 
 	protected static EList allOwnedElements(Element element,
