@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005, 2006 IBM Corporation and others.
+ * Copyright (c) 2005, 2007 IBM Corporation and others.
  * All rights reserved.   This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -8,7 +8,7 @@
  * Contributors:
  *   IBM - initial API and implementation
  *
- * $Id: PackageOperations.java,v 1.27 2006/05/29 20:29:25 khussey Exp $
+ * $Id: PackageOperations.java,v 1.27.2.3 2007/02/01 18:42:22 khussey Exp $
  */
 package org.eclipse.uml2.uml.internal.operations;
 
@@ -123,7 +123,7 @@ public class PackageOperations
 		protected void copyAttribute(EAttribute eAttribute, EObject eObject,
 				EObject copyEObject) {
 
-			if (eObject.eIsSet(eAttribute)) {
+			if (!eAttribute.isUnsettable() || eObject.eIsSet(eAttribute)) {
 
 				try {
 					if (eAttribute.getEType().eClass().getClassifierID() == EcorePackage.EENUM) {
@@ -184,20 +184,32 @@ public class PackageOperations
 					EList values = (EList) eObject.eGet(eAttribute);
 
 					for (int i = 0, size = values.size(); i < size; i++) {
-						copyValues.add(i, targetEEnum.getEEnumLiteral(
-							((EEnumLiteral) values.get(i)).getName())
-							.getInstance());
+						EEnumLiteral value = targetEEnum
+							.getEEnumLiteral(((EEnumLiteral) values.get(i))
+								.getName());
+
+						if (value != null) {
+							copyValues.add(value.getInstance());
+						}
 					}
 				} else {
-					copyValues.add(targetEEnum.getEEnumLiteral(
-						((EEnumLiteral) eObject.eGet(eAttribute)).getName())
-						.getInstance());
+					EEnumLiteral value = targetEEnum
+						.getEEnumLiteral(((EEnumLiteral) eObject
+							.eGet(eAttribute)).getName());
+
+					if (value != null) {
+						copyValues.add(value.getInstance());
+					}
 				}
 			} else {
-				copyEObject.eSet(targetEAttribute, targetEEnum.getEEnumLiteral(
-					((EEnumLiteral) (eAttribute.isMany()
+				EEnumLiteral value = targetEEnum
+					.getEEnumLiteral(((EEnumLiteral) (eAttribute.isMany()
 						? ((EList) eObject.eGet(eAttribute)).get(0)
-						: eObject.eGet(eAttribute))).getName()).getInstance());
+						: eObject.eGet(eAttribute))).getName());
+
+				if (value != null) {
+					copyEObject.eSet(targetEAttribute, value.getInstance());
+				}
 			}
 		}
 
@@ -311,12 +323,6 @@ public class PackageOperations
 					UMLPlugin.INSTANCE.log(e);
 				}
 			}
-
-			try {
-				super.copyReference(eReference, eObject, copyEObject);
-			} catch (Exception e) {
-				UMLPlugin.INSTANCE.log(e);
-			}
 		}
 	}
 
